@@ -1,7 +1,7 @@
 package Perinci::Sub::To::POD;
 
-our $DATE = '2015-09-26'; # DATE
-our $VERSION = '0.67'; # VERSION
+our $DATE = '2015-09-29'; # DATE
+our $VERSION = '0.68'; # VERSION
 
 use 5.010001;
 use Log::Any::IfLOG '$log';
@@ -181,6 +181,17 @@ sub after_gen_doc {
     $self->add_doc_lines($self->_md2pod($dres->{description}), "")
         if $dres->{description};
 
+    {
+        my $export = $self->{export} // 0;
+        if ($export == 0) {
+            $self->add_doc_lines(__("This function is not exported by default, but exportable."), "");
+        } elsif ($export == 1) {
+            $self->add_doc_lines(__("This function is exported by default."), "");
+        } elsif ($export == -1) {
+            $self->add_doc_lines(__("This function is not exportable."), "");
+        }
+    }
+
     my $feat = $meta->{features} // {};
     my @ft;
     my %spargs;
@@ -345,7 +356,7 @@ Perinci::Sub::To::POD - Generate POD documentation from Rinci function metadata
 
 =head1 VERSION
 
-This document describes version 0.67 of Perinci::Sub::To::POD (from Perl distribution Perinci-To-Doc), released on 2015-09-26.
+This document describes version 0.68 of Perinci::Sub::To::POD (from Perl distribution Perinci-To-Doc), released on 2015-09-29.
 
 =head1 SYNOPSIS
 
