@@ -1,7 +1,7 @@
 package Perinci::To::POD;
 
-our $DATE = '2015-09-26'; # DATE
-our $VERSION = '0.67'; # VERSION
+our $DATE = '2015-09-29'; # DATE
+our $VERSION = '0.68'; # VERSION
 
 use 5.010001;
 use Log::Any::IfLOG '$log';
@@ -87,7 +87,13 @@ sub gen_doc_section_description {
 
 sub _gen_func_doc {
     my $self = shift;
-    my $o = Perinci::Sub::To::POD->new(_pa => $self->{_pa}, @_);
+    my %args = @_;
+
+    my $o = Perinci::Sub::To::POD->new(
+        _pa => $self->{_pa},
+        export => $self->{exports} ? $self->{exports}{$args{name}} : undef,
+        %args,
+    );
     $o->gen_doc;
     $o->doc_lines;
 }
@@ -104,9 +110,6 @@ sub gen_doc_section_functions {
 
     $self->SUPER::gen_doc_section_functions;
 
-    # XXX if module uses Perinci::Exporter, show a basic usage for importing and
-    # show exportability information
-
     # XXX categorize functions based on tags?
     for my $furi (sort keys %{ $dres->{functions} }) {
         $self->add_doc_lines("");
@@ -153,7 +156,7 @@ Perinci::To::POD - Generate POD documentation for a package from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.67 of Perinci::To::POD (from Perl distribution Perinci-To-Doc), released on 2015-09-26.
+This document describes version 0.68 of Perinci::To::POD (from Perl distribution Perinci-To-Doc), released on 2015-09-29.
 
 =head1 SYNOPSIS
 
